declare namespace material {
  /**
   * 申请单明细
   */
  export interface ApplyDetail {
    /** 申请单ID */
    applyId?: number;

    /** 确认数量 */
    confirmQuantity?: number;

    /** createdTime */
    createdTime?: string;

    /** 异常情况说明 */
    exceptionRemark?: string;

    /** id */
    id?: number;

    /** 物料Id */
    materialId?: number;

    /** 申请数量 */
    quantity?: number;

    /** updatedTime */
    updatedTime?: string;
  }

  /**
   * 入库/出库/盘点 申请单
   */
  export interface ApplyForm {
    /** 申请人 */
    applicant?: string;

    /** 申请日期 */
    applyDate?: string;

    /** 盘点类型（1: 全盘 2: 部分盘点） */
    auditType?: 'ALL' | 'PARTIAL';

    /** auditTypeInfo */
    auditTypeInfo?: material.Codebook;

    /** createdTime */
    createdTime?: string;

    /** 异常原因 */
    exception?: string;

    /** 处理方式(0-无需处理 1-忽略并修改库存 2-补充库存 3-其他) */
    handle?: 'NO_ACTION' | 'IGNORE_AND_SAVE' | 'REPLENISH' | 'OTHER';

    /** handleInfo */
    handleInfo?: material.Codebook;

    /** id */
    id?: number;

    /** 是否确认（0: 未确认 1: 已确认） */
    isConfirm?: boolean;

    /** 结果(系统自动生成) */
    result?: string;

    /** 类型（1: 采购入库申请 2: 归还入库申请 3: 出库外借申请 4: 盘点申请） */
    type?: 'PURCHASE_RECEIPT' | 'RETURN_RECEIPT' | 'LOAN_OUT' | 'AUDIT';

    /** typeInfo */
    typeInfo?: material.Codebook;

    /** updatedTime */
    updatedTime?: string;
  }

  /**
   * 申请单
   */
  export interface ApplyInfo {
    /** 申请单明细 */
    applyDetails?: Array<material.ApplyDetail>;

    /** applyForm */
    applyForm?: material.ApplyForm;

    /** 扫码的条码集合 */
    detailList?: Array<material.MaterialStockDetail>;
  }

  /**
   * 物料信息
   */
  export interface Material {
    /** 赋码规则(0-低值易耗品（不参与赋码） 1-高价值工具类（参与唯一赋码） */
    assignRule?: 'LOW_VALUE' | 'HIGH_VALUE';

    /** assignRuleInfo */
    assignRuleInfo?: material.Codebook;

    /** 编码 */
    code?: string;

    /** createdTime */
    createdTime?: string;

    /** 备注 */
    description?: string;

    /** id */
    id?: number;

    /** 名称 */
    name?: string;

    /** 规格 */
    spec?: string;

    /** 库存数量 */
    stock?: number;

    /** 类型 */
    type?: string;

    /** updatedTime */
    updatedTime?: string;
  }

  /**
   * 物料明细数据表
   */
  export interface MaterialStockDetail {
    /** 入库申请单 */
    applyId?: number;

    /** 条码 */
    barcode?: string;

    /** createdTime */
    createdTime?: string;

    /** id */
    id?: number;

    /** 物料ID */
    materialId?: number;

    /** 状态 */
    status?: 'IN' | 'OUT' | 'OFF';

    /** statusInfo */
    statusInfo?: material.Codebook;

    /** updatedTime */
    updatedTime?: string;
  }
}
